@@ -154,8 +154,7 @@ void utility::openPath( const QString& path,const QString& opener,const QString&
 
 		if( failed && obj ){
 
-			DialogMsg m( obj ) ;
-			m.ShowUIOK( title,msg ) ;
+			DialogMsg( obj ).ShowUIOK( title,msg ) ;
 		}
 	} ) ;
 }
@@ -438,8 +437,7 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the \
 GNU General Public License for more details.\n\
 " ).arg( VERSION_STRING ) ;
 
-	DialogMsg m( parent ) ;
-	m.ShowUIInfo( QObject::tr( "about SiriKali" ),license ) ;
+	DialogMsg( parent ).ShowUIInfo( QObject::tr( "about SiriKali" ),true,license ) ;
 }
 
 static utility::array_t _default_dimensions( const char * defaults )
@@ -950,28 +948,32 @@ void utility::autoMountFavoritesOnStartUp( bool e )
 	_settings->setValue( "AutoMountFavoritesOnStartUp",e ) ;
 }
 
-void utility::autoMountBackEnd( LXQt::Wallet::BackEnd e )
+void utility::autoMountBackEnd( const utility::walletBackEnd& e )
 {
-	_settings->setValue( "AutoMountPassWordBackEnd",[ e ](){
+	_settings->setValue( "AutoMountPassWordBackEnd",[ & ]()->QString{
 
-		if( e == LXQt::Wallet::BackEnd::internal ){
+		if( e.isInvalid() ){
 
-			return QString( "internal" ) ;
+			return "none" ;
+
+		}else if( e == LXQt::Wallet::BackEnd::internal ){
+
+			return "internal" ;
 
 		}else if( e == LXQt::Wallet::BackEnd::libsecret ){
 
-			return QString( "libsecret" ) ;
+			return "libsecret" ;
 
 		}else if( e == LXQt::Wallet::BackEnd::kwallet ){
 
-			return QString( "kwallet" ) ;
+			return "kwallet" ;
 		}else{
-			return QString( "internal" ) ;
+			return "none" ;
 		}
 	}() ) ;
 }
 
-LXQt::Wallet::BackEnd utility::autoMountBackEnd()
+utility::walletBackEnd utility::autoMountBackEnd()
 {
 	if( _settings->contains( "AutoMountPassWordBackEnd" ) ){
 
@@ -984,8 +986,12 @@ LXQt::Wallet::BackEnd utility::autoMountBackEnd()
 		}else if( e == "kwallet" ){
 
 			return LXQt::Wallet::BackEnd::kwallet ;
-		}else{
+
+		}else if( e == "internal" ){
+
 			return LXQt::Wallet::BackEnd::internal ;
+		}else{
+			return utility::walletBackEnd() ;
 		}
 	}else{
 		_settings->setValue( "AutoMountPassWordBackEnd",QString( "internal" ) ) ;
@@ -1024,3 +1030,14 @@ void utility::showMountDialogWhenAutoMounting( bool e )
 {
 	_settings->setValue( "ShowMountDialogWhenAutoMounting",e ) ;
 }
+
+int utility::checkForUpdateInterval()
+{
+	if( _settings->contains( "checkForUpdateInterval" ) ){
+
+		return _settings->value( "checkForUpdateInterval" ).toInt() * 1000 ;
+	}else{
+		_settings->setValue( "checkForUpdateInterval",int( 300 ) ) ;
+		return 300 * 1000 ;
+	}
+}
